@@ -6,8 +6,8 @@ import subprocess
 import sys
 import tempfile
 
-from typing import Dict
-from tuxrun.__main__ import KERNELS
+from typing import Dict, Any
+from tuxrun.devices import Device
 from tuxrun.yaml import yaml_load
 
 
@@ -16,7 +16,7 @@ from tuxrun.yaml import yaml_load
 ###########
 def get_results(tmpdir: Path) -> Dict:
     required_keys = set(["msg", "lvl", "dt"])
-    res = {}
+    res: Dict[Any, Any] = {}
     data = yaml_load((tmpdir / "logs.yaml").read_text(encoding="utf-8"))
 
     if data is None:
@@ -117,10 +117,9 @@ def run(device, test, runtime, debug):
 # Entrypoint #
 ##############
 def main():
+    devices = [d for d in Device.list() if d.startswith("qemu-")]
     parser = argparse.ArgumentParser(description="Integration tests")
-    parser.add_argument(
-        "--devices", default=list(KERNELS.keys()), nargs="+", help="devices"
-    )
+    parser.add_argument("--devices", default=devices, nargs="+", help="devices")
     parser.add_argument(
         "--tests",
         default=[
